from setuptools import setup

setup(name = "test_by_prem",
        version="0.1",
        description = "package for clothing, \n\
                        contains shirt and pants",
        packages = ["clothing"],
        zip_safe = False
        )